==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/SzablonWydruku.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypSzablonuWydruku;
import pl.topteam.dps.enums.TypWzorca;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class SzablonWydruku extends GenericDPSObject {
    /**
     * SZABLON_WYDRUKU.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * SZABLON_WYDRUKU.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * SZABLON_WYDRUKU.TYP_WZORCA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypWzorca typWzorca;

    /**
     * SZABLON_WYDRUKU.TYP_SZABLONU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypSzablonuWydruku typSzablonu;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SZABLON_WYDRUKU.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SZABLON_WYDRUKU.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SZABLON_WYDRUKU.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * SZABLON_WYDRUKU.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return SZABLON_WYDRUKU.TYP_WZORCA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypWzorca getTypWzorca() {
        return typWzorca;
    }

    /**
     * SZABLON_WYDRUKU.TYP_WZORCA
     *
     * @param typWzorca
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTypWzorca(TypWzorca typWzorca) {
        this.typWzorca = typWzorca;
    }

    /**
     * @return SZABLON_WYDRUKU.TYP_SZABLONU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypSzablonuWydruku getTypSzablonu() {
        return typSzablonu;
    }

    /**
     * SZABLON_WYDRUKU.TYP_SZABLONU
     *
     * @param typSzablonu
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTypSzablonu(TypSzablonuWydruku typSzablonu) {
        this.typSzablonu = typSzablonu;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SzablonWydruku other = (SzablonWydruku) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getTypWzorca() == null ? other.getTypWzorca() == null : this.getTypWzorca().equals(other.getTypWzorca()))
            && (this.getTypSzablonu() == null ? other.getTypSzablonu() == null : this.getTypSzablonu().equals(other.getTypSzablonu()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getTypWzorca() == null) ? 0 : getTypWzorca().hashCode());
        result = prime * result + ((getTypSzablonu() == null) ? 0 : getTypSzablonu().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", typWzorca=").append(typWzorca);
        sb.append(", typSzablonu=").append(typSzablonu);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/SzablonWydruku.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypSzablonuWydruku;
import pl.topteam.dps.enums.TypWzorca;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class SzablonWydruku extends GenericDPSObject {
    /**
     * SZABLON_WYDRUKU.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * SZABLON_WYDRUKU.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * SZABLON_WYDRUKU.TYP_WZORCA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypWzorca typWzorca;

    /**
     * SZABLON_WYDRUKU.TYP_SZABLONU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypSzablonuWydruku typSzablonu;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SZABLON_WYDRUKU.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SZABLON_WYDRUKU.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SZABLON_WYDRUKU.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * SZABLON_WYDRUKU.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return SZABLON_WYDRUKU.TYP_WZORCA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypWzorca getTypWzorca() {
        return typWzorca;
    }

    /**
     * SZABLON_WYDRUKU.TYP_WZORCA
     *
     * @param typWzorca
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTypWzorca(TypWzorca typWzorca) {
        this.typWzorca = typWzorca;
    }

    /**
     * @return SZABLON_WYDRUKU.TYP_SZABLONU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypSzablonuWydruku getTypSzablonu() {
        return typSzablonu;
    }

    /**
     * SZABLON_WYDRUKU.TYP_SZABLONU
     *
     * @param typSzablonu
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTypSzablonu(TypSzablonuWydruku typSzablonu) {
        this.typSzablonu = typSzablonu;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SzablonWydruku other = (SzablonWydruku) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getTypWzorca() == null ? other.getTypWzorca() == null : this.getTypWzorca().equals(other.getTypWzorca()))
            && (this.getTypSzablonu() == null ? other.getTypSzablonu() == null : this.getTypSzablonu().equals(other.getTypSzablonu()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getTypWzorca() == null) ? 0 : getTypWzorca().hashCode());
        result = prime * result + ((getTypSzablonu() == null) ? 0 : getTypSzablonu().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", typWzorca=").append(typWzorca);
        sb.append(", typSzablonu=").append(typSzablonu);
        sb.append("]");
        return sb.toString();
    }
}
